# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from stigg._vendors.pydantic import Field

from .base_model import BaseModel
from .fragments import PageInfoFragment, SubscriptionQueryFragment


class Subscriptions(BaseModel):
    subscriptions: "SubscriptionsSubscriptions"


class SubscriptionsSubscriptions(BaseModel):
    edges: List["SubscriptionsSubscriptionsEdges"]
    page_info: "SubscriptionsSubscriptionsPageInfo" = Field(alias="pageInfo")


class SubscriptionsSubscriptionsEdges(BaseModel):
    node: "SubscriptionsSubscriptionsEdgesNode"


class SubscriptionsSubscriptionsEdgesNode(SubscriptionQueryFragment):
    pass


class SubscriptionsSubscriptionsPageInfo(PageInfoFragment):
    pass


Subscriptions.model_rebuild()
SubscriptionsSubscriptions.model_rebuild()
SubscriptionsSubscriptionsEdges.model_rebuild()
